@@ -8,7 +8,7 @@ from multiprocessing import Process, Pipe
 from bfit.gui.calculator_nqr_B0 import current2field
 from bfit.gui.calculator_nqr_B0_hh6 import current2field as current2field_hh6
 from bfit.backend.fitdata import fitdata
-from bdata import bdata
+from bdata import bdata, bmerged
 from bfit import logger_name
 
 import numpy as np
@@ -85,10 +85,10 @@ class fileviewer(object):
         self.rebin.set(1)
         
         self.entry_year = Spinbox(entry_frame, \
-                from_=2000, to=datetime.datetime.today().year, 
+                from_=2000, to=np.inf, 
                 textvariable=self.year, width=5)
         self.entry_runn = Spinbox(entry_frame, \
-                from_=0, to=50000, 
+                from_=0, to=np.inf, 
                 textvariable=self.runn, width=7)
         self.runn.set(40000)
         
@@ -402,7 +402,7 @@ class fileviewer(object):
             key_order_sw.append('')
         
         # rates and counts
-        hist = ('F+', 'F-', 'B-', 'B+') if data.area == 'BNMR' \
+        hist = ('F+', 'F-', 'B-', 'B+') if data.area.upper() == 'BNMR' \
                                      else ('L+', 'L-', 'R-', 'R+')
 
         try:     
@@ -1389,9 +1389,29 @@ class fileviewer(object):
             if run is False:
                 return False
         
+        # check for merged runs
+        if run > 50000:
+            
+            # split run number
+            run = str(run)
+            run = [int(run[i:i+5]) for i in range(0, len(run), 5)]
+            
+            # split year number - note to self: update in 1000 years
+            if year > 3000:
+                year = str(year)
+                year = [int(year[i:i+4]) for i in range(0, len(year), 4)]
+            else:
+                year = [year]*len(run)
+            
+            # get data
+            data = bmerged([bdata(r, year=y) for r, y in zip(run, year)])
+            
+        else:
+            data = bdata(run, year=year)
+        
         self.logger.info('Fetching run %s from %s', run, year)
         
-        return self._get_data(bdata(run, year=year), quiet=quiet)
+        return self._get_data(data, quiet=quiet)
         
     # ======================================================================= #
     def load_file(self, filename=None):
